import logging
from ca_pwt.helpers.graph_api import EntityAPI, APIResponse
from ca_pwt.helpers.utils import assert_condition

_logger = logging.getLogger(__name__)


class ServicePrincipalsAPI(EntityAPI):
    def _get_entity_path(self) -> str:
        return "servicePrincipals"

    def get_by_app_id(self, app_id: str) -> APIResponse:
        """Gets service principal found with the given app_id
        Returns an API_Response object and the entity is in the json property of the API_Response object
        """
        assert_condition(app_id, "app_id cannot be None")
        url = f"{self.entity_url}(appId='" + "{" + app_id + "}')"
        self._logger.info(url)
        return self._request_get(url=url)


_BUILTIN_APPS_ID_NAME = {
    "All": "All",
    "None": "None",
    "Office365": "Office365",
    "b28ec8e1-950e-4bd0-b3d0-c1e93074b88b": "Azure Gallery RP",
    "75513c96-801d-4559-830a-6754de13dd19": "M365 Label Analytics",
    "55bdc56c-2b15-4538-aa37-d0c008c8c430": "IC3 Gateway TestClone",
    "3138fe80-4087-4b04-80a6-8866c738028a": "SharePoint Notification Service",
    "fc780465-2017-40d4-a0c5-307022471b92": "WindowsDefenderATP",
    "eec53b1f-b9a4-4479-acf5-6b247c6a49f2": "Microsoft.HybridCompute Agent Service",
    "abba844e-bc0e-44b0-947a-dc74e5d09022": "Domain Controller Services",
    "e036f41b-7edf-47ee-b373-b4b374a2e33c": "Modern Workplace App Diagnostic Authenticator",
    "0000000c-0000-0000-c000-000000000000": "Microsoft App Access Panel",
    "74cb6831-0dbb-4be1-8206-fd4df301cdc2": "Azure Service Fabric Resource Provider",
    "8b62382d-110e-4db8-83a6-c7e8ee84296a": "PowerAI",
    "fd642066-7bfc-4b65-9463-6a08841c12f0": "Microsoft Purview Platform",
    "342f61e2-a864-4c50-87de-86abc6790d49": "Power Platform Policy Services CM - PROD",
    "6bccf540-eb86-4037-af03-7fa058c2db75": "Geneva Alert RP",
    "585fc3c3-9a59-4720-8319-53cce041a605": "Azure Arc Appliance Resource Provider",
    "06dd8193-75af-46d0-84bb-9b9bcaa89e8b": "SubstrateActionsService",
    "4c1a3aed-b389-4824-99b0-514c07906851": "Intune DeviceCheckIn ConfidentialClient",
    "224a7b82-46c9-4d6b-8db0-7360fb444681": "Microsoft Modern Contact Master",
    "1e2ca66a-c176-45ea-a877-e87f7231e0ee": "Microsoft B2B Admin Worker",
    "7e9f2fca-0cd8-4a6c-a1a0-7ffe48aec7c6": "Intune Remote Help",
    "6b91db1b-f05b-405a-a0b2-e3f60b28d645": "M365 Admin Services",
    "00000007-0000-0000-c000-000000000000": "Dataverse",
    "76c92352-c057-4cc2-9b1e-f34c32bc58bd": "Azure Container Registry Application",
    "e08ab642-962a-4175-913c-165f557d799a": "teams contacts griffin processor",
    "98785600-1bb7-4fb9-b9fa-19afe2c8a360": "Azure Security Insights",
    "1f5530b3-261a-47a9-b357-ded261e17918": "Azure Multi-Factor Auth Connector",
    "e8ab36af-d4be-4833-a38b-4d6cf1cfd525": "Microsoft Social Engagement",
    "1ac05c7e-12d2-4605-bf9d-549d7041c6b3": "Microsoft Azure Synapse Gateway",
    "e1979c22-8b73-4aed-a4da-572cc4d0b832": "App Studio for Microsoft Teams",
    "38d143fa-a9d8-4e3e-b073-81f3fefeaf95": "Microsoft Teams IP Core Service",
    "5741a1ff-751d-4ad7-bcd1-dfe3c998fd11": "StoragePool Resource Provider",
    "e97edbaf-39b2-4546-ba61-0a24e1bef890": "Teams EHR Connector",
    "3957683c-3a48-4a6c-8706-a6e2d6883b02": "Omnichannel for CS Provisioning App Primary",
    "b8066b99-6e67-41be-abfa-75db1a2c8809": "Microsoft Intune IW Service",
    "aeb86249-8ea3-49e2-900b-54cc8e308f85": "M365 License Manager",
    "3f6aecb4-6dbf-4e45-9141-440abdced562": "PROD Microsoft Defender For Cloud XDR",
    "11c174dc-1945-4a9a-a36b-c79a0f246b9b": "Azure Monitor System",
    "c9299480-c13a-49db-a7ae-cdfe54fe0313": "PowerApps-Advisor",
    "978877ea-b2d6-458b-80c7-05df932f3723": "Microsoft Teams AuditService",
    "80a10ef9-8168-493d-abf9-3297c4ef6e3c": "Microsoft.ServiceBus",
    "81473081-50b9-469a-b9d8-303109583ecb": "Cortana Runtime Service",
    "70dcc41e-5abf-4ecd-b017-d5c7370e58fe": "Intune SidecarService ConfidentialClient",
    "00000003-0000-0000-c000-000000000000": "Microsoft Graph",
    "7dd7250c-c317-4bc6-8528-8d27b02707ef": "ZTNA Data Acquisition - PROD",
    "cb43afba-eb6b-4cef-bf00-758b6c233beb": "Azure OSSRDBMS MySQL Flexible Server BYOK",
    "b4bddae8-ab25-483e-8670-df09b9f1d0ea": "Signup",
    "9e4a5442-a5c9-4f6f-b03f-5b9fcaaf24b1": "OfficeServicesManager",
    "cedebc57-38a2-4f0a-8472-dfcbba5b04c6": "M365 Compliance Drive",
    "408992c7-2af6-4ff1-92e3-65b73d2b5092": "Azure Search Management",
    "56c1da01-2129-48f7-9355-af6d59d42766": "Graph Connector Service",
    "359431ad-ece5-496b-8768-be4bbfd82f36": "ECP Billing Service",
    "c9a559d2-7aab-4f13-a6ed-e7e9c52aec87": "Microsoft Forms",
    "61c50b89-703d-431d-8d80-1e8618748775": "Azure Machine Learning OpenAI",
    "a4c95b9e-3994-40cc-8953-5dc66d48348d": "Microsoft Container Registry",
    "7cd684f4-8a78-49b0-91ec-6a35d38739ba": "Azure Logic Apps",
    "8338dec2-e1b3-48f7-8438-20c30a534458": "ViewPoint",
    "9d8f559b-5984-46a4-902a-ad4271e83efa": "Power Virtual Agents Service",
    "0af06dc6-e4b5-4f28-818e-e78e62d137a5": "Windows 365",
    "9e133cac-5238-4d1e-aaa0-d8ff4ca23f4e": "Conferencing Virtual Assistant",
    "38808189-fa7a-4d8a-807f-eba01edacca6": "AzNet Security Guard",
    "049d4938-2ef2-4274-aa8f-630fc9bc33d1": "Microsoft.Blockchain",
    "c495cfdc-814f-46a1-89f0-657921c9fbe0": "Azure AD Identity Governance - Dynamics 365 Management",
    "3e36f539-fc2c-479c-90fb-3cfa21da3a4b": "Power Platform Environment Discovery Service",
    "2220bbc4-4518-4fef-aac6-c6f32e9f9fd1": "Customer Experience Platform PROD",
    "f53895d3-095d-408f-8e93-8f94b391404e": "Portfolios",
    "167e2ded-f32d-49f5-8a10-308b921bc7ee": "OCaaS Worker Services",
    "0000001b-0000-0000-c000-000000000000": "Microsoft Power BI Information Service",
    "c476eb34-4c94-43bc-97fc-94ede0534615": "AzUpdateCenterBilling",
    "ea62c1c6-550b-4238-8ea7-c55a85d86be8": "Teams Work Report",
    "5ebe1e69-13dd-4953-84fa-a74ed591db2e": "Microsoft Arcadia Spark Service",
    "d9327919-6775-4843-9037-3fb0fb0473cb": "Databricks Resource Provider",
    "9e5d84af-8971-422f-968a-354cd675ae5b": "ComplianceAuthServer",
    "3c31d730-a768-4286-a972-43e9b83601cd": "Demeter.WorkerRole",
    "9cb77803-d937-493e-9a3b-4b49de3f5a74": "Microsoft Intune Service Discovery",
    "11cd3e2e-fccb-42ad-ad00-878b93575e07": "Automated Call Distribution",
    "50d8616b-fd4f-4fac-a1c9-a6a9440d7fe0": "OMSAuthorizationServicePROD",
    "499b84ac-1321-427f-aa17-267ca6975798": "Azure DevOps",
    "79d7fb34-4bef-4417-8184-ff713af7a679": "Azure Bastion",
    "19dd5b37-d116-48cb-90d2-4aa56696cba1": "Microsoft Forms Pro",
    "0cd196ee-71bf-4fd6-a57c-b491ffd4fb1e": "Media Analysis and Transformation Service",
    "d32c68ad-72d2-4acb-a0c7-46bb2cf93873": "Microsoft Activity Feed Service",
    "5da7367f-09c8-493e-8fd4-638089cddec3": "CABProvisioning",
    "1e70cd27-4707-4589-8ec5-9bd20c472a46": "Skype Presence Service",
    "5b712e99-51a3-41ce-86ff-046e0081c5c0": "Marketplace SaaS v2",
    "96ff4394-9197-43aa-b393-6a41652e21f8": "Power Virtual Agents ",
    "1fec8e78-bce4-4aaf-ab1b-5451cc387264": "Microsoft Teams",
    "d8877f27-09c0-43aa-8113-40151dae8b14": "Microsoft Intune AndroidSync",
    "39e6ea5b-4aa4-4df2-808b-b6b5fb8ada6f": "Dynamics Provision",
    "33be1cef-03fb-444b-8fd3-08ca1b4d803f": "OneDrive Web",
    "7dcff627-a295-4553-9229-b1f3513f82a8": "Power Platform Data Analytics",
    "2f5afa01-cdcb-4707-a62a-0803cc994c60": "MS-CE-CXG-MAC-AadShadowRoleWriter",
    "507a7586-da5c-4e86-80f2-2bc2e55ae394": "Surface Dashboard",
    "ec245c98-4a90-40c2-955a-88b727d97151": "Azure AD Identity Governance - Directory Management",
    "d88a361a-d488-4271-a13f-a83df7dd99c2": "IDML Graph Resolver Service and CAD",
    "6a0ec4d3-30cb-4a83-91c0-ae56bc0e3d26": "Azure Container Registry",
    "47ee738b-3f1a-4fc7-ab11-37e4822b007e": "Azure AD Application Proxy",
    "dbcbd02a-d7c4-42fb-8c27-b07e5118b848": "Azure Graph",
    "e3335adb-5ca0-40dc-b8d3-bedc094e523b": "SubscriptionRP",
    "0000000a-0000-0000-c000-000000000000": "Microsoft Intune",
    "4bfd5d66-9285-44a1-bb14-14953e8cdf5e": "Audit GraphAPI Application",
    "89d10474-74af-4874-99a7-c23c2f643083": "Azure Iot Hub",
    "c10f411a-874c-485c-9d66-6e0b34202c41": "SEAL SNI",
    "0a5f63c0-b750-4f38-a71c-4fc0d58b89e2": "Microsoft Mobile Application Management",
    "d6037e40-282c-493d-8f63-f255e36c6ef4": "Microsoft Dynamics 365 Supply Chain Visibility",
    "257601fd-462f-4a21-b623-7f719f0f90f4": "Centralized Deployment",
    "c7d28c4f-0d2c-49d6-a88d-a275cc5473c7": "AIRS",
    "57fb890c-0dab-4253-a5e0-7188c88b2bb4": "SharePoint Online Client",
    "8f41dc7c-542c-4bdd-8eb3-e60543f607ca": "Microsoft Device Directory Service",
    "bf8eb16c-7ba7-4b47-86be-ac5e4b2007a5": "Microsoft.CustomProviders RP",
    "0032593d-6a05-4847-8ca4-4b6220ed2a1e": "Microsoft_Azure_ELMAdmin",
    "da9b70f6-5323-4ce6-ae5c-88dcc5082966": "Universal Print",
    "14452459-6fa6-4ec0-bc50-1528a1a06bf0": "Intune CMDeviceService",
    "9e09aefc-b2e5-4d19-9f74-3e3e8b11a57b": "Microsoft Azure Synapse Resource Provider",
    "c728155f-7b2a-4502-a08b-b8af9b269319": "AAD Request Verification Service - PROD",
    "f5223e1a-4d50-4fda-9049-55d819fbb03e": "Customer Experience Platform CDPA Provisioning TIP Non-Prod",
    "a303894e-f1d8-4a37-bf10-67aa654a0596": "Compute Usage Provider",
    "9cd0f7df-8b1a-4e54-8c0c-0ef3a51116f6": "DirectoryLookupService",
    "b61cc489-e138-4a69-8bf3-c2c5855c8784": "Azure Spring Cloud DiagSettings App",
    "be1918be-3fe3-4be9-b32b-b542fc27f02e": "M365 Compliance Drive Client",
    "911e905a-a50e-4c94-9f7c-48bb12f549ed": "Azure Blockchain Service",
    "aad3e70f-aa64-4fde-82aa-c9d97a4501dc": "RPA - Machine Management Relay Service",
    "7cf4b8a3-78fd-4d1d-8019-d5041c61ce64": "Azure MFA Management",
    "c7ddd9b4-5172-4e28-bd29-1e0792947d18": "Microsoft Mixed Reality",
    "5b404cf4-a79d-4cfe-b866-24bf8e1a4921": "Bot Service Token Store",
    "0736f41a-0425-4b46-bdb5-1563eff02385": "Azure Machine Learning",
    "7319c514-987d-4e9b-ac3d-d38c4f427f4c": "AzureContainerService",
    "d29a4c00-4966-492a-84dd-47e779578fb7": "Discovery Service",
    "64b12d6e-6549-484c-8cc6-6281839ba394": "KCS-UserRP",
    "05a65629-4c1b-48c1-a78b-804c4abdd4af": "Microsoft Cloud App Security",
    "b7912db9-aa33-4820-9d4f-709830fdd78f": "ConnectionsService",
    "27a762be-14e7-4f92-899c-151877d6d497": "Bot Service CMEK Prod",
    "df09ff61-2178-45d8-888c-4210c1c7b0b2": "O365 UAP Processor",
    "0c708d37-30b2-4f22-8168-5d0cba6f37be": "Microsoft Teams Partner Tenant Administration ",
    "8ee8fdad-f234-4243-8f3b-15c294843740": "Microsoft Threat Protection",
    "48af08dc-f6d2-435f-b2a7-069abd99c086": "Connectors",
    "58c746b0-a0b0-4647-a8f6-12dde5981638": "Azure AD Identity Governance Insights",
    "38df11dd-582e-4207-be6f-b214675f44a1": "SEAL All credentials",
    "d87dcbc6-a371-462e-88e3-28ad15ec4e64": "Domain Controller Services",
    "262044b1-e2ce-469f-a196-69ab7ada62d3": "Backup Management Service",
    "74bcdadc-2fdc-4bb3-8459-76d06952a0e9": "Microsoft Intune Web Company Portal",
    "7a274595-3618-4e6f-b54e-05bb353e0153": "Teams NRT DLP Service",
    "f6b60513-f290-450e-a2f3-9930de61c5e7": "Microsoft Azure Log Search Alerts",
    "5d661950-3475-41cd-a2c3-d671a3162bc1": "Microsoft Outlook",
    "c98e5057-edde-4666-b301-186a01b4dc58": "MicrosoftEndpointDLP",
    "9bdab391-7bbe-42e8-8132-e4491dc29cc0": "Azure Backup NRP Application",
    "b8340c3b-9267-498f-b21a-15d5547fd85e": "Hyper-V Recovery Manager",
    "8bdebf23-c0fe-4187-a378-717ad86f6a53": "ResourceHealthRP",
    "b8cf62f3-7cc7-4e32-ab3a-41370ef0cfcf": "Azure Machine Learning Services Asset Notification",
    "5e3ce6c0-2b1f-4285-8d4b-75ee78787346": "Microsoft Teams Web Client",
    "7f15f9d9-cad0-44f1-bbba-d36650e07765": "Azure Synapse Link for Dataverse",
    "05d97c70-cb7c-4e66-8138-d5ca7c59d206": "Azure Edge Zones storage backend",
    "1c827867-9069-4bde-8155-1a0267a3dea5": "Microsoft DataMovement Metadata Service",
    "0d38933a-0bbd-41ca-9ebd-28c4b5ba7cb7": "Office365 Zoom",
    "04436913-cf0d-4d2a-9cc6-2ffe7f1d3d1c": "Windows Notification Service",
    "e95a6071-4f90-4971-84e2-492d9323345b": "CosmosDBMongoClusterPrivateEndpoint",
    "6f7d0213-62b1-43a8-b7f4-ff2bb8b7b452": "Dual-write",
    "341b7f3d-69b3-47f9-9ce7-5b7f4945fdbd": "Azure Support - Network Watcher",
    "f18474f2-a66a-4bb0-a3c9-9b8d892092fa": "MaintenanceResourceProvider",
    "c94526fa-9f4b-4d30-99f5-849636e4552f": "Office 365 Client Insights Substrate Services Prod",
    "546068c3-99b1-4890-8e93-c8aeadcfe56a": "Common Data Service - Azure Data Lake Storage",
    "4747d38e-36c5-4bc3-979b-b0ef74df54d1": "PushChannel",
    "c8f5141d-83e0-4e9a-84d0-bb6677e26f64": "Azure Guest Container Update Manager",
    "9c60a40b-b5c5-4d01-8588-776209c80db3": "Search Federation Connector - Dataverse",
    "7df0a125-d3be-4c96-aa54-591f83ff541c": "Microsoft Flow Service",
    "bf04bdab-e06f-44f3-9821-d3af64fc93a9": "Dynamics 365 Fraud Protection",
    "507bc9da-c4e2-40cb-96a7-ac90df92685c": "Office 365 Reports",
    "8909aac3-be91-470c-8a0b-ff09d669af91": "Microsoft Parature Dynamics CRM",
    "3603eff4-9141-41d5-ba8f-02fb3a439cd6": "Diagnostic Services Data Access",
    "bb2a64ee-5d29-4b07-a491-25806dc854d3": "Verifiable Credentials Service",
    "9ea1ad79-fdb6-4f9a-8bc3-2b70f96e34c7": "Bing",
    "905fcf26-4eb7-48a0-9ff0-8dcc7194b5ba": "Sway",
    "8bbf8725-b3ca-4468-a217-7c8da873186e": "DeploymentScheduler",
    "93bd1aa4-c66b-4587-838c-ffc3174b5f13": "Power Platform Global Discovery Service",
    "44a02aaa-7145-4925-9dcd-79e6e1b94eff": "Microsoft Dynamics 365 Apps Integration",
    "f9d02341-e7aa-456d-926d-4a0ca599fbee": "Office 365 Enterprise Insights",
    "bf9fc203-c1ff-4fd4-878b-323642e462ec": "Jarvis Transaction Service",
    "660d4be7-2665-497f-9611-a42c2668dbce": "Microsoft Fluid Framework Preview",
    "62c559cd-db0c-4da0-bab2-972528c65d42": "ACR-Tasks-Network",
    "a1bfe852-bf44-4da0-a9c1-37af2d5e6df9": "Microsoft Graph Bicep Extension",
    "1762e607-063e-431a-a25a-f0f782acb73b": "Virtual Connector Provider",
    "ccf4d8df-75ce-4107-8ea5-7afd618d4d8a": "Microsoft Intune AAD BitLocker Recovery Key Integration",
    "0c6620df-7b29-44de-8ba4-688a56a20f9f": "Azure Marketplace Datadog",
    "0f698dd4-f011-4d23-a33e-b36416dcb1e6": "OfficeClientService",
    "7b58f833-4438-494c-a724-234928795a67": "Directory and Policy Cache",
    "7c33bfcb-8d33-48d6-8e60-dc6404003489": "Network Watcher",
    "996def3d-b36c-4153-8607-a6fd3c01b89f": "Dynamics 365 Business Central",
    "707be275-6b9d-4ee7-88f9-c0c2bd646e0f": "Dynamic Alerts",
    "78462efa-e271-409c-a90b-ce3fbd93538a": "Microsoft Teams Admin Gateway Service",
    "62b732f7-fc71-40bc-b27d-35efcb0509de": "Microsoft Teams AadSync",
    "87223343-80b1-4097-be13-2332ffa1d666": "Outlook Web App Widgets",
    "aa813f0e-407a-459d-93af-805f2bf10f33": "Substrate Conversation Intelligence Service",
    "b7faa489-a4c8-4b39-bb0c-842c3de2de6a": "EASM API",
    "d6101214-691f-47d0-8ea3-dca752e62d71": "Dataverse Resource Provider",
    "58ef1dbd-684c-47d6-8ffc-61ea7a197b95": "AzNS EventHub Action",
    "c066d759-24ae-40e7-a56f-027002b5d3e4": "M365DataAtRestEncryption",
    "707aa1ac-be0a-478d-9ce7-0d2765a5c1d6": "Funnel and Engagement Data Service",
    "579d9c9d-4c83-4efc-8124-7eba65ed3356": "Azure Compute",
    "4ac7d521-0382-477b-b0f8-7e1d95f85ca2": "Azure Analysis Services",
    "bd6d9218-235b-4abd-b3be-9ff157dcf36c": "MDC Data Sensitivity",
    "a4a365df-50f1-4397-bc59-1a1564b8bb9c": "Microsoft Remote Desktop",
    "8b3391f4-af01-4ee8-b4ea-9871b2499735": "O365 Secure Score",
    "71234da4-b92f-429d-b8ec-6e62652e50d7": "Microsoft Customer Engagement Portal",
    "66c23536-2118-49d3-bc66-54730b057680": "Skype Core Calling Service",
    "c9224372-5534-42cb-a48b-8db4f4a3892e": "MS Teams Griffin Assistant",
    "75e725bf-66ce-4cea-9b9a-5c4caae57f33": "Azure API for DICOM",
    "a0be0c72-870e-46f0-9c49-c98333a996f7": "AzureDnsFrontendApp",
    "3cf6df92-2745-4f6f-bbcf-19b59bcdb62a": "Office 365 Client Admin",
    "6a0a243c-0886-468a-a4c2-eff52c7445da": "Application Insights Configuration Service",
    "f1346770-5b25-470b-88bd-d5744ab7952c": "Intune Autopilot ConfidentialClient",
    "60e6cd67-9c8c-4951-9b3c-23c25a2169af": "Managed Disks Resource Provider",
    "66244124-575c-4284-92bc-fdd00e669cea": "IAMTenantCrawler",
    "63ea3c01-7483-456e-8073-d3fed34fbdda": "Azure Container Scale Sets - CS2",
    "925eb0d0-da50-4604-a19f-bd8de9147958": "Groupies Web Service",
    "273404b8-7ebc-4360-9f90-b40417f77b53": "Microsoft Exact Data Match Service",
    "c7bb12bf-0b39-4f7f-9171-f418ff39b76a": "Azure Lab Services",
    "7d312290-28c8-473c-a0ed-8e53749b6d6d": "Microsoft Cognitive Services",
    "607e1f95-b519-4bac-8a15-6196f40e8977": "StreamToSubstrateRepl",
    "510a5356-1745-4855-93a5-113ea589fb26": "Microsoft 365 Ticketing",
    "8c59ead7-d703-4a27-9e55-c96a0054c8d2": "My Profile",
    "1996141e-2b07-4491-927a-5a024b335c78": "Microsoft Teams UIS",
    "63e61dc2-f593-4a6f-92b9-92e4d2c03d4f": "Microsoft Intune SCCM Connector",
    "2ff814a6-3304-4ab8-85cb-cd0e6f879c1d": "AzureDatabricks",
    "461e8683-5575-4561-ac7f-899cc907d62a": "Azns AAD Webhook",
    "5a4a238f-f186-4fff-95bd-d3e70f9e1a08": "Privacy Management",
    "e18cedde-9458-482f-9dd1-558c597ac42e": "Hybrid Connectivity RP",
    "ae11f5fb-c627-4eec-b4a0-f7b5969426e5": "Liftr Datadog RPaaS",
    "a07d3a2b-436e-40ce-9eba-4e5a5664f14c": "Enterprise File Sync Service",
    "8c8fbf21-0ef3-4f60-81cf-0df811ff5d16": "Power Query Online GCC-L5",
    "82f45fb0-18b4-4d68-8bed-9e44909e3890": "Meeting Migration Service",
    "0000001a-0000-0000-c000-000000000000": "MicrosoftAzureActiveAuthn",
    "9d06afd9-66c9-49a6-b385-ea7509332b0b": "O365SBRM Service",
    "1c2909a7-6432-4263-a70d-929a3c1f9ee5": "Common Data Service License Management",
    "0000000b-0000-0000-c000-000000000000": "Microsoft Seller Dashboard",
    "b6b84568-6c01-4981-a80f-09da9a20bbed": "Microsoft Invoicing",
    "7f0d9978-eb2a-4974-88bd-f22a3006fe17": "Intune DiagnosticService",
    "00000007-0000-0ff1-ce00-000000000000": "Microsoft Exchange Online Protection",
    "981f26a1-7f43-403b-a875-f8b09b8cd720": "Azure Multi-Factor Auth Client",
    "7e313d81-57dd-4bdd-906e-337963583de3": "Intune DeviceDirectory ConfidentialClient",
    "ea2f600a-4980-45b7-89bf-d34da487bda1": "Microsoft.Azure.DomainRegistration",
    "a855a166-fd92-4c76-b60d-a791e0762432": "Microsoft Teams VSTS",
    "3340b944-b12e-47d0-b46b-35f08ec1d8ee": "SPAuthEvent",
    "feff8b5b-97f3-4374-a16a-1911ae9e15e9": "Cloud Hybrid Search",
    "2b8844d8-6c87-4fce-97a0-fbec9006e140": "AssistAPI",
    "48ac35b8-9aa8-4d74-927d-1f4a14a0b239": "Skype and Teams Tenant Admin API",
    "f71766dc-90d9-4b7d-bd9d-4499c4331c3f": "Azure Blueprints",
    "00695ed2-3202-4156-8da1-69f60065e255": "Microsoft Visio Data Visualizer",
    "3af5adde-460d-4bc1-ada0-fc648af8fefb": "ChatMigrationService1P",
    "f2c304cf-8e7e-4c3f-8164-16299ad9d272": "Azure Management Groups",
    "601d4e27-7bb3-4dee-8199-90d47d527e1c": "Office Change Management",
    "d10de03d-5ba3-497a-90e6-7ff8c9736059": "Atlas",
    "c5393580-f805-4401-95e8-94b7a6ef2fc2": "Office 365 Management APIs",
    "8ae6a0b1-a07f-4ec9-927a-afb8d39da81c": "Microsoft Device Management EMM API",
    "1b489150-9b00-413a-83fd-6ef8f05b6e28": "Policy Processor",
    "9cdead84-a844-4324-93f2-b2e6bb768d07": "Azure Virtual Desktop",
    "6872b314-67ab-4a16-98e7-a663b0f772c3": "Office365 Shell SS-Server Default",
    "93efed00-6552-4119-833a-422b297199f9": "Meru19 First Party App",
    "c4ce8d07-0c1e-418d-8777-dc2d1e452061": "Microsoft Defender for Cloud Azure Discovery",
    "f3723d34-6ff5-4ceb-a148-d99dcd2511fc": "Bot Framework Dev Portal",
    "a85cf173-4192-42f8-81fa-777a763e6e2c": "Azure Virtual Desktop Client",
    "37182072-3c9c-4f6a-a4b3-b3f91cacffce": "AzureSupportCenter",
    "18a4ad1e-427c-4cad-8416-ef674e801d32": "Intune DeviceActionService",
    "3e050dd7-7815-46a0-8263-b73168a42c10": "Teams Approvals",
    "a57aca87-cbc0-4f3c-8b9e-dc095fdc8978": "IAM Supportability",
    "c58637bb-e2e1-4312-8a00-04b5ffcd3403": "SharePoint Online Client Extensibility",
    "6bb8e274-af5d-4df2-98a3-4fd78b4cafd9": "Azure Container Instance Service",
    "ba23cd2a-306c-48f2-9d62-d3ecd372dfe4": "DecomOfficeGraph",
    "64f79cb9-9c82-4199-b85b-77e35b7dcbcb": "Microsoft Teams Bots",
    "c39c9bac-9d1f-4dfb-aa29-27f6365e5cb7": "Azure Advisor",
    "913c6de4-2a4a-4a61-a9ce-945d2b2ce2e0": "Dynamics Lifecycle services",
    "44b7b882-eb46-485c-9c78-686f6b67b176": "AML Registries",
    "192644fe-6aac-4786-8d93-775a056aa1de": "MIP Exchange Solutions - SPO",
    "475226c6-020e-4fb2-8a90-7a972cbfc1d4": "PowerApps Service",
    "394866fc-eedb-4f01-8536-3ff84b16be2a": "Microsoft People Cards Service",
    "ab158d9a-0b5c-4cc3-bb2b-f6646581e4e4": "CAP Neptune Prod CM Prod ",
    "4392ab71-2ce2-4b0d-8770-b352745c73f5": "HPC Cache Resource Provider",
    "f5c26e74-f226-4ae8-85f0-b4af0080ac9e": "Application Insights API",
    "765fe668-04e7-42ba-aec0-2c96f1d8b652": "Exchange Office Graph Client for AAD - Noninteractive",
    "584a29b4-7876-4445-921e-71e427d4f4b3": "Azure Spring Apps Domain-Management Dogfood",
    "2793995e-0a7d-40d7-bd35-6968ba142197": "My Apps",
    "0eda3b13-ddc9-4c25-b7dd-2f6ea073d6b7": "Microsoft Flow CDS Integration Service",
    "5a543d7c-9c4a-4f90-8cc7-6ae082a5b65b": "Azure HDInsight Surrogate Service",
    "5861f7fb-5582-4c1a-83c0-fc5ffdb531a6": "Azure RBAC Data Plane",
    "61c28d8b-814f-4a57-9c7f-8cd0580aead2": "Iris Provider EOP Web Service",
    "e406a681-f3d4-42a8-90b6-c2b029497af1": "Azure Storage",
    "123cd850-d9df-40bd-94d5-c9f07b7fa203": "Azure OSSRDBMS Database",
    "e3583ad2-c781-4224-9b91-ad15a8179ba0": "Microsoft.ExtensibleRealUserMonitoring",
    "e9c19b55-5325-4cf3-a268-e380bc74c907": "Microsoft_EMM_ModernWorkplace",
    "dbc36ae1-c097-4df9-8d94-343c3d091a76": "Service Encryption",
    "7865c1d2-f040-46cc-875f-831a1ef6a28a": "Azure HDInsight Cluster API",
    "bf26f092-3426-4a99-abfb-97dad74e661a": "Azure AD Identity Governance",
    "d82073ec-4d7c-4851-9c5d-5d97a911d71d": "Kaizala Sync Service",
    "5657e26c-cc92-45d9-bc47-9da6cfdb4ed9": "Azure OSSRDBMS PostgreSQL Flexible Server AAD Authentication",
    "e1335bb1-2aec-4f92-8140-0e6e61ae77e5": "CIWebService",
    "022907d3-0f1b-48f7-badc-1ba6abab6d66": "Azure SQL Database",
    "de17788e-c765-4d31-aba4-fb837cfff174": "Skype for Business Management Reporting and Analytics - Legacy",
    "d9d5c99e-b0b4-4bad-92cc-5a6eb5421985": "M365 Lighthouse Service",
    "3bc2296e-aa22-4ed2-9e1e-946d05afa6a2": "SharePoint Online Web Client Extensibility Isolated",
    "61d02d70-ab6c-4569-be48-787ea2cda65d": "Dynamics 365 Analytics",
    "94c63fef-13a3-47bc-8074-75af8c65887a": "Office Delve",
    "9f6c88b7-0272-4581-a75a-ec0340824ed1": "PTSS",
    "c4288165-6698-45ba-98a5-48ea7791fed3": "Azure Service Connector Resource Provider",
    "c44b4083-3bb0-49c1-b47d-974e53cbdf3c": "Azure Portal",
    "120d688d-1518-4cf7-bd38-182f158850b6": "Azure Time Series Insights",
    "328fd23b-de6e-462c-9433-e207470a5727": "NFV Resource Provider",
    "c2ada927-a9e2-4564-aae2-70775a2fa0af": "OCaaS Client Interaction Service",
    "a0f92522-89de-4c5e-9a75-0044ccf66efd": "ClusterConfigToArcZone",
    "00000001-0000-0000-c000-000000000000": "Azure ESTS Service",
    "5b20c633-9a48-4a5f-95f6-dae91879051f": "Azure Information Protection",
    "bb2a2e3a-c5e7-4f0a-88e0-8e01fd3fc1f4": "CPIM Service",
    "3cf798a6-b0c5-4d5c-9645-b5273d471fc5": "teamsupgradeorchestrator-app",
    "ea890292-c8c8-4433-b5ea-b09d0668e1a6": "Azure Credential Configuration Endpoint Service",
    "15689b28-1333-4213-bb64-38407dde8a5e": "Microsoft Azure",
    "2e458d69-0892-4655-b713-4f7b182315dd": "Microsoft.BareBoneClusterService",
    "557c67cf-c916-4293-8373-d584996f60ae": "Configuration Manager Microservice",
    "e4ab13ed-33cb-41b4-9140-6e264582cf85": "Azure SQL Database Backup To Azure Backup Vault",
    "cbfda01c-c883-45aa-aedc-e7a484615620": "Microsoft Windows AutoPilot Service API",
    "aa9ecb1e-fd53-4aaa-a8fe-7a54de2c1334": "Office 365 Configure",
    "f25a7567-8ec5-4582-8a65-bfd66b0530cc": "ReportReplica",
    "8d3a7d3c-c034-4f19-a2ef-8412952a9671": "Microsoft Office Licensing Service",
    "12743ff8-d3de-49d0-a4ce-6c91a4245ea0": "Metrics Monitor API",
    "481115cb-6d15-4cc0-8caf-f2fee7bfbd2b": "IC3 Modern Effective Config Worker",
    "36e2398c-9dd3-4f29-9a72-d9f2cfc47ad9": "CosmosDB Dedicated Instance",
    "88884730-8181-4d82-9ce2-7d5a7cc7b81e": "SharePoint Notification Service",
    "184909ca-69f1-4368-a6a7-c558ee6eb0bd": "Marketplace Caps API",
    "60ca1954-583c-4d1f-86de-39d835f3e452": "Radius Aad Syncer",
    "a25dbca8-4e60-48e5-80a2-0664fdb5c9b6": "Microsoft.MileIQ",
    "00f82732-f451-4a01-918c-0e9896e784f9": "Skype for Business Application Configuration Service",
    "c6871074-3ded-4935-a5dc-b8f8d91d7d06": "ISV Portal",
    "3af5a1e8-2459-45cb-8683-bcd6cccbcc13": "Azure Smart Alerts",
    "bb8f18b0-9c38-48c9-a847-e1ef3af0602d": "Microsoft.Azure.ActiveDirectoryIUX",
    "02e3ae74-c151-4bda-b8f0-55fbf341de08": "Application Registration Portal",
    "d5097d05-956f-4ae2-b6a2-eff25f5689b3": "Windows Update for Business Cloud Extensions PowerShell",
    "69cc3193-b6c4-4172-98e5-ed0f38ab3ff8": "Windows 365 Ibiza Extension",
    "fd225045-a727-45dc-8caa-77c8eb1b9521": "Azure Help Resource Provider",
    "ddc728e9-153d-4032-ab80-80e57af7a56f": "Azure Monitor for VMs",
    "31ba6d5c-2e14-40fb-bbcb-27dc8a1bfaf5": "TeamsLinkedInLiveApp",
    "cb1bda4c-1213-4e8b-911a-0a8c83c5d3b7": "o365.servicecommunications.microsoft.com",
    "19947cfd-0303-466c-ac3c-fcc19a7a1570": "Azure DNS",
    "dee7ba80-6a55-4f3b-a86c-746a9231ae49": "Microsoft AppPlat EMA",
    "76c7f279-7959-468f-8943-3954880e0d8c": "Azure SQL Managed Instance to Microsoft.Network",
    "39aaf054-81a5-48c7-a4f8-0293012095b9": "IC3 Gateway",
    "ca7f3f0b-7d91-482c-8e09-c5d840d0eac5": "Log Analytics API",
    "8bea2130-23a1-4c09-acfb-637a9fb7c157": "M365 Pillar Diagnostics Service API",
    "99045fe1-7639-4a75-9d4a-577b6ca3810f": "Azure Active Directory Authentication Extensions",
    "9b06ebd4-9068-486b-bdd2-dac26b8a5a7a": "Microsoft.DynamicsMarketing",
    "6da466b6-1d13-4a2c-97bd-51a99e8d4d74": "Exchange Office Graph Client for AAD - Interactive",
    "c9475445-9789-4fef-9ec5-cde4a9bcd446": "Messaging Bot API Application for GCC",
    "607ece82-f922-494f-88b8-30effaf12214": "Azure Machine Learning Singularity",
    "9bb724a5-4639-438c-969b-e184b2b1e264": "KaizalaActionsPlatform",
    "166f1b03-5b19-416f-a94b-1d7aa2d247dc": "Office Hive",
    "562db366-1b96-45d2-aa4a-f2148cef2240": "Diagnostic Services Trusted Storage Access",
    "27b24f1f-688b-4661-9594-0fdfde972edc": "Skype Business Voice Directory",
    "0517ffae-825d-4aff-999e-3f2336b8a20a": "M365 App Management Service",
    "6a8b4b39-c021-437c-b060-5a14a3fd65f3": "Verifiable Credentials Service Admin",
    "3db474b9-6a0c-4840-96ac-1fceb342124f": "Verifiable Credentials Service Request",
    "f448d7e5-e313-4f90-a3eb-5dbb3277e4b3": "Media Recording for Dynamics 365 Sales",
    "163b648b-025e-455b-9937-a7f39a65d171": "SSO Extension Intune",
    "50e95039-b200-4007-bc97-8d5790743a63": "Azure Virtual Desktop ARM Provider",
    "28ec9756-deaf-48b2-84d5-a623b99af263": "Office Personal Assistant at Work Service",
    "dae89220-69ba-4957-a77a-47b78695e883": "Universal Print Native Client",
    "00000012-0000-0000-c000-000000000000": "Microsoft Rights Management Services",
    "08e18876-6177-487e-b8b5-cf950c1e598c": "SharePoint Online Web Client Extensibility",
    "d9ce8cfa-8bd8-4ff1-b39b-5e5dd5742935": "Omnichannel for CS CRM ClientApp Primary",
    "880da380-985e-4198-81b9-e05b1cc53158": "Azure Cognitive Search",
    "7b7531ad-5926-4f2d-8a1d-38495ad33e17": "Azure Advanced Threat Protection",
    "6d32b7f8-782e-43e0-ac47-aaad9f4eb839": "Permission Service O365",
    "3caf7e80-c1dc-4cbc-811c-d281c9d5e45c": "Microsoft.NotificationHubs",
    "2b61b865-d0bd-4c60-9efa-6fa934eefaac": "TrustedPublishersProxyService",
    "d4ebce55-015a-49b5-a083-c84d1797ae8c": "Microsoft Intune Enrollment",
    "4660504c-45b3-4674-a709-71951a6b0763": "Microsoft Invitation Acceptance Portal",
    "e6650347-047f-4e51-9386-839384472ea5": "Bot Service Resource Provider",
    "789997c7-d888-4475-a0a0-35014494de85": "Modern Workplace Management",
    "ab27a73e-a3ba-4e43-8360-8bcc717114d8": "Microsoft.OfficeModernCalendar",
    "37ccb541-667a-4428-947a-f5dda698fa3c": "MARS",
    "270efc09-cd0d-444b-a71f-39af4910ec45": "Windows Cloud Login",
    "a99783bc-5466-4cef-82eb-ebf285d77131": "Common Job Provider",
    "fa3d9a0c-3fb0-42cc-9193-47c7ecd2edbd": "Microsoft Partner Center",
    "fb9de05a-fecc-4642-b3ca-66b9d4434d4d": "Azure Machine Learning Authorization App 1",
    "9d777fa9-b417-43b8-8991-12f8ee2161d2": "Liftr Elastic RPaaS",
    "6b11041d-54a2-4c4f-96a2-6053efe46d8b": "HoloLens Camera Roll Upload",
    "8602e328-9b72-4f2d-a4ae-1387d013a2b3": "Azure API Management",
    "00000009-0000-0000-c000-000000000000": "Power BI Service",
    "2b479c68-8d9b-4e27-9d85-5d74803de734": "Virtual Visits App",
    "ef947699-9b52-4b31-9a37-ef325c6ffc47": "Power Query Online GCC-L4",
    "7bf610f7-ecaf-43a2-9dbc-33b14314d6fe": "Microsoft.SecurityDevOps Resource Provider",
    "1341df96-0b28-43da-ba24-7a6ce39be816": "Azure Managed HSM RP",
    "794ded15-70c6-4bcd-a0bb-9b7ad530a01a": "Microsoft Intune Advanced Threat Protection Integration",
    "e81c7467-0fc3-4866-b814-c973488361cd": "AzureBackup_Fabric_Service",
    "e6f9f783-1fdb-4755-acaf-abed6c642885": "Meru19 MySQL First Party App",
    "6abc93dc-978e-48a3-8e54-458e593ed8cf": "Customer Service Trial PVA - readonly",
    "f5aeb603-2a64-4f37-b9a8-b544f3542865": "Microsoft Teams RetentionHook Service",
    "e158eb19-34ac-4d1b-a930-ec92172f7a97": "Audit Search Api Service",
    "32597670-3e15-4def-8851-614ff48c1efa": "Container Marketplace Package App",
    "c830ddb0-63e6-4f22-bd71-2ad47198a23e": "Microsoft To-Do",
    "60b2e7d5-a27f-426d-a6b1-acced0846fdf": "IpAddressManager",
    "2f6713e6-1e21-4a83-91b4-5bf9a2378f81": "Dynamics 365 Resource Scheduling Optimization",
    "f7069a8d-9edc-4300-b365-ae53c9627fc4": "Microsoft.MileIQ.Dashboard",
    "c03594ff-1168-40fb-aef7-eb9f1edf7278": "Enterprise File Sync Admin Service",
    "d2fa1650-4805-4a83-bcb9-cf41fe63539c": "ACR-Tasks-Prod",
    "30e31aeb-977f-4f4f-a483-b61e8377b302": "Microsoft Teams ADL",
    "e95d8bee-4725-4f59-910d-94d415da51b9": "Skype for Business Name Dictionary Service",
    "56823b05-67d8-413a-b6ab-ad19d7710cf2": "CAS API Security RP",
    "a232010e-820c-4083-83bb-3ace5fc29d0b": "Azure Cosmos DB",
    "8cae6e77-e04e-42ce-b5cb-50d82bce26b1": "Microsoft Policy Insights Provider Data Plane",
    "823c0a78-5de0-4445-a7f5-c2f42d7dc89b": "EventGrid Data API",
    "61ae9cd9-7bca-458c-affc-861e2f24ba3b": "Windows Update for Business Deployment Service",
    "6ea8091b-151d-447a-9013-6845b83ba57b": "AD Hybrid Health",
    "4f547b5f-c3f7-4d2c-a14f-0f8f1286d7d5": "OneDriveLTI",
    "21ab802f-8580-4be3-a767-576c283a82f5": "Modern Workplace Core ITaaS",
    "b4fa09d8-5da5-4352-83d9-05c2a44cf431": "Azure CosmosDB for PostgreSQL AAD Authentication",
    "61a63147-3824-45f5-a186-ace3f4c9daeb": "MsgDataMgmt",
    "99335b6b-7d9d-4216-8dee-883b26e0ccf7": "Power Platform Dataflows Common Data Service Client",
    "18a66f5f-dbdf-4c17-9dd7-1634712a9cbe": "Azure Machine Learning Services",
    "bf4fa6bf-d24c-4d1c-8cfd-12063dd646b2": "AADPremiumService",
    "bb55177b-a7d9-4939-a257-8ab53a3b2bc6": "Azure Arc Data Services",
    "2f3f02c9-5679-4a5c-a605-0de55b07d135": "Office 365 Information Protection",
    "e3cf99e1-a6e5-4284-9f92-261c7713bc54": "Customer Experience Platform CDPA Provisioning PROD",
    "a164aee5-7d0a-46bb-9404-37421d58bdf7": "Microsoft Teams AuthSvc",
    "9d4afbbc-06a4-49e0-8005-4e5afd1d4fec": "ZTNA Network Access Control Plane",
    "66f1e791-7bfb-4e18-aed8-1720056421c7": "Microsoft Azure Stream Analytics",
    "4580fd1d-e5a3-4f56-9ad1-aab0e3bf8f76": "Call Recorder",
    "cc15fd57-2c6c-4117-a88c-83b1d56b4bbe": "Microsoft Teams Services",
    "62fd1447-0ef3-4ab7-a956-7dd05232ecc1": "Office Scripts Service",
    "de096ee1-dae7-4ee1-8dd5-d88ccc473815": "MileIQ Admin Center",
    "ec52d13d-2e85-410e-a89a-8c79fb6a32ac": "Azure Synapse Studio",
    "703e2651-d3fc-48f5-942c-74274233dba8": "Microsoft Dynamics ERP Microservices CDS",
    "1d78a85d-813d-46f0-b496-dd72f50a3ec0": "Microsoft Azure Policy Insights",
    "959678cf-d004-4c22-82a6-d2ce549a58b8": "Microsoft_Azure_Support",
    "e29b5c86-b9ab-4a86-9a20-d10842007599": "SharePoint Framework Azure AD Helper",
    "eaf8a961-f56e-47eb-9ffd-936e22a554ef": "DecomDevilFish",
    "87749df4-7ccf-48f8-aa87-704bad0e0e16": "Microsoft Teams - Device Admin Agent",
    "eacba838-453c-4d3e-8c6a-eb815d3469a3": "Microsoft Flow CDS Integration Service TIP1",
    "d00b5d58-cae5-42ad-ae0a-5a2e6f7ee6c9": "Arc Token Service",
    "189cf920-d3d8-4133-9145-23adcc6824fa": "IpLicensingService",
    "6f0478d5-61a3-4897-a2f2-de09a5a90c7f": "WindowsUpdate-Service",
    "09a984f4-014c-43de-ae0c-7ec73dc053d3": "BenefitsFD",
    "c5b17a4f-cc6f-4649-9480-684280a2af3a": "aciapi",
    "1cda9b54-9852-4a5a-96d4-c2ab174f9edf": "O365Account",
    "bd9b7cd5-dac1-495f-b013-ac871e98fa5f": "ClusterConfigResourceSync",
    "a8b6bf88-1d1a-4626-b040-9a729ea93c65": "Compute Artifacts Publishing Service",
    "b97b6bd4-a49f-4a0c-af18-af507d1da76c": "Office Shredding Service",
    "982bda36-4632-4165-a46a-9863b1bbcf7d": "O365 Demeter",
    "e933bd07-d2ee-4f1d-933c-3752b819567b": "Azure Monitor Control Service",
    "6204c1d1-4712-4c46-a7d9-3ed63d992682": "Microsoft Flow Portal",
    "3aa5c166-136f-40eb-9066-33ac63099211": "O365 Customer Monitoring",
    "c94ede5f-b856-405a-bcd9-406285330a76": "PrivacyEngine",
    "7c0a6aea-533c-458c-9f81-15568f10f6e4": "Windows 365 IW Service",
    "3edcf11f-df80-41b2-a5e4-7e213cca30d1": "Azure Application Change Service",
    "5b81a823-5f67-4fb3-8d0f-4c92b5044fe4": "Liftr Elastic Whale Worker",
    "918d0db8-4a38-4938-93c1-9313bdfe0272": "asmcontainerimagescanner",
    "bbb94529-53a3-4be5-a069-7eaf2712b826": "Verifiable Credential Request Service",
    "6d057c82-a784-47ae-8d12-ca7b38cf06b4": "Networking-MNC",
    "0ef94e72-e4fc-4aa0-a8f4-ff27deb3e6eb": "Teams NRT DLP Ingestion Service",
    "2233b157-f44d-4812-b777-036cdaf9a96e": "Azure Cloud Shell",
    "18af356b-c4fd-4f52-9899-d09d21397ab7": "Office365DirectorySynchronizationService",
    "443155a6-77f3-45e3-882b-22b3a8d431fb": "Domain Controller Services",
    "6682cfa5-2710-44c9-adb8-5ac9d76e394a": "MTS",
    "b46c3ac5-9da6-418f-a849-0a07a10b3c6c": "Cloud Infrastructure Entitlement Management",
    "d828acde-4b48-47f5-a6e8-52460104a052": "Automanage API Access",
    "4f6778d8-5aef-43dc-a1ff-b073724b9495": "Azure Healthcare APIs",
    "e8de9221-a19c-4c81-b814-fd37c6caf9d2": "Azure Spring Cloud Resource Provider",
    "40775b29-2688-46b6-a3b5-b256bd04df9f": "Microsoft Information Protection API",
    "2e49aa60-1bd3-43b6-8ab6-03ada3d9f08b": "Dynamics Data Integration",
    "23c898c1-f7e8-41da-9501-f16571f8d097": "OCPS Checkin Service",
    "91bb937c-29c2-4275-982f-9465f0caf03d": "Microsoft.Relay",
    "9449a792-6831-40e2-9097-29dbc6dd4753": "Arc Public Cloud - Networking",
    "cf53fce8-def6-4aeb-8d30-b158e7b1cf83": "Microsoft Stream Portal",
    "eb070ea5-bd17-41f1-ad68-5851f6e71774": "Service Bus MSI App",
    "644c1b11-f63f-45fa-826b-a9d2801db711": "CompliancePolicy",
    "ba9ff945-a723-4ab5-a977-bd8c9044fe61": "My Staff",
    "00000005-0000-0000-c000-000000000000": "Microsoft Azure Workflow",
    "a6943a7f-5ba0-4a34-bf91-ab439efdda3f": "Azure HDInsight on AKS Client",
    "a882f5bd-2492-44fe-bb55-a811aab59451": "Intune Compliance Client Prod",
    "b5a60e17-278b-4c92-a4e2-b9262e66bb28": "Azure MFA StrongAuthenticationService",
    "3184af01-7a88-49e0-8b55-8ecdce0aa950": "Azure Cost Management XCloud",
    "8a753eec-59bc-4c6a-be91-6bf7bfe0bcdf": "Teams Application Gateway",
    "a3dfc3c6-2c7d-4f42-aeec-b2877f9bce97": "Microsoft Azure AD Identity Protection",
    "00edd498-7c0c-4e68-859c-5a55d518c9c0": "Teams CMD Services and Data",
    "00000002-0000-0ff1-ce00-000000000000": "Office 365 Exchange Online",
    "4990cffe-04e8-4e8b-808a-1175604b879f": "Microsoft Partner",
    "cb4dc29f-0bf4-402a-8b30-7511498ed654": "Power BI Premium",
    "7557eb47-c689-4224-abcf-aef9bd7573df": "Skype for Business",
    "e1829006-9cf1-4d05-8b48-2e665cb48e6a": "Microsoft Teams Web Client",
    "161a339d-b9f5-41c5-8856-6a6669acac64": "Microsoft Azure Alerts Management",
    "d7097cd1-c779-44d0-8c71-ab1f8386a97e": "Microsoft Office Licensing Service Agents",
    "a3747411-ce7c-4888-9ddc-3a230786ca19": "Azure Container Registry - Dataplane",
    "f416c5fc-9ac4-4f66-a8e5-cb203139cbe4": "OCPS Admin Service",
    "1a14be2a-e903-4cec-99cf-b2e209259a0f": "Azure Lab Services",
    "e935b4a5-8968-416d-8414-caed51c782a9": "MicrosoftGuestConfiguration",
    "478d8d1a-326f-49da-a58e-8f576faa4b5e": "Threat Intelligence Portal",
    "354b5b6d-abd6-4736-9f51-1be80049b91f": "Microsoft Mobile Application Management Backend",
    "c505e273-0ba0-47e7-a0bd-f48042b4524d": "AzureBackup_WBCM_Service",
    "4cba1704-a0c1-45ee-9d41-fe75b4ef9190": "TeamsChatServiceApp",
    "6e99704e-62d5-40f6-b2fe-90aafbe3a710": "OCaaS Experience Management Service",
    "d2a590e7-6906-4a45-8f41-cecfdca9bca1": "Hybrid RP Application",
    "9191c4da-09fe-49d9-a5f1-d41cbe92ad95": "Azure HDInsight Service",
    "d2a0a418-0aac-4541-82b2-b3142c89da77": "Microsoft Operations Management Suite",
    "98db8bd6-0cc0-4e67-9de5-f187f1cd1b41": "Microsoft Substrate Management",
    "0cd79364-7a90-4354-9984-6e36c841418d": "Access IoT Hub Device Provisioning Service",
    "b1379a75-ce5e-4fa3-80c6-89bb39bf646c": "Microsoft Teams Chat Aggregator",
    "fd14a986-6fe4-409a-883e-cdec1009cd54": "Intune Grouping and Targeting Client Prod",
    "db040338-7cb4-44df-a22b-785bde7ce0e2": "RPA - Machine Management Relay Service - Application",
    "67e3df25-268a-4324-a550-0de1c7f97287": "Office Online Service LEGACY",
    "64a7b174-5779-4506-b54c-fbb0d80f1c9b": "CMAT",
    "4c8f074c-e32b-4ba7-b072-0f39d71daf51": "IPSubstrate",
    "0c7668b5-3260-4ad0-9f53-34ed54fa19b2": "Microsoft Defender for Cloud Servers Scanner Resource Provider",
    "331cc017-5973-4173-b270-f0042fddfd75": "Power Apps API",
    "5e5e43d4-54da-4211-86a4-c6e7f3715801": "Azure Regional Service Manager",
    "aa580612-c342-4ace-9055-8edee43ccb89": "Microsoft Teams Shifts",
    "0eb4bf93-cb63-4fe1-9d7d-70632ccf3082": "Microsoft Teams Intelligent Workspaces Interactions Service",
    "603b8c59-ba28-40ff-83d1-408eee9a93e5": "Verifiable Credentials Issuer Service",
    "372140e0-b3b7-4226-8ef9-d57986796201": "Azure Windows VM Sign-In",
    "ba1ea022-5807-41d5-bbeb-292c7e1cf5f6": "Azure Maps",
    "51df634f-ddb4-4901-8a2d-52f6393a796b": "Azure Region Move Orchestrator Application",
    "93625bc8-bfe2-437a-97e0-3d0060024faa": "Microsoft password reset service",
    "8e0e8db5-b713-4e91-98e6-470fed0aa4c2": "Microsoft Azure Signup Portal",
    "aacceff9-8ec3-413c-83eb-cb131aaf55c6": "Arc Public Cloud - Servers",
    "22d27567-b3f0-4dc2-9ec2-46ed368ba538": "Reading Assignments",
    "21a8a852-89f4-4947-a374-b26b2db3d365": "IC3 Long Running Operations Service",
    "5a807f24-c9de-44ee-a3a7-329e88a00ffc": "Messaging Bot API Application",
    "0469d4cd-df37-4d93-8a61-f8c75b809164": "Policy Administration Service",
    "bf283ae6-5efd-44a8-b56a-2a7939982d60": "Azure Machine Learning Authorization App 2",
    "de247707-4e4a-47d6-89fd-3c632f870b34": "CloudLicensingSystem",
    "8c420feb-03df-47cc-8a05-55df0cf3064b": "AzureUpdateCenter",
    "00000006-0000-0ff1-ce00-000000000000": "Microsoft Office 365 Portal",
    "0f6edad5-48f2-4585-a609-d252b1c52770": "AIGraphClient",
    "a1b76039-a76c-499f-a2dd-846b4cc32627": "Azure Key Vault Managed HSM Key Governance Service",
    "1b730954-1685-4b74-9bfd-dac224a7b894": "Azure Active Directory PowerShell",
    "66c6d0d1-f2e7-4a18-97a9-ed10f3347016": "Managed Service",
    "bc59ab01-8403-45c6-8796-ac3ef710b3e3": "Outlook Online Add-in App",
    "ddbf3205-c6bd-46ae-8127-60eb93363864": "Microsoft Azure Batch",
    "894b1496-c6e0-4001-b69c-81b327564ca4": "Azure Healthcare APIs Resource Provider",
    "b20d0d3a-dc90-485b-ad11-6031e769e221": "SalesInsightsWebApp",
    "bb3d68c2-d09e-4455-94a0-e323996dbaa3": "Medeina Service",
    "486c78bf-a0f7-45f1-92fd-37215929e116": "GatewayRP",
    "29f411f1-b2cf-4043-8ac8-2185d7316811": "Azure Iot Hub Publisher App",
    "bb5ffd56-39eb-458c-a53a-775ba21277da": "Medeina Portal",
    "a15bc1de-f777-408f-9d2b-a27ed19c72ba": "ASA Curation Web Tool",
    "ae04d195-7aae-4ed7-800c-cfed140e3b1b": "Business Scenario Service",
    "cfa8b339-82a2-471a-a3c9-0fc0be7a4093": "Azure Key Vault",
    "73c2949e-da2d-457a-9607-fcc665198967": "Azure Purview",
    "1609d3a1-0db2-4818-b854-fe1614f0718a": "Azure Edge Zones storage",
    "de926fbf-e23b-41f9-ae15-c943a9cfa630": "Microsoft Azure Authorization Private Link Provider",
    "3734c1a4-2bed-4998-a37a-ff1a9e7bf019": "Microsoft Azure Container Apps - Data Plane",
    "75efb5bc-18a1-4e7b-8a66-2ad2503d79c6": "Microsoft Teams Retail Service",
    "5b534afd-fdc0-4b38-a77f-af25442e3149": "Microsoft Support Diagnostics",
    "a0551534-cfc9-4e1f-9a7a-65093b32bb38": "AzureLockbox",
    "bd93b475-f9e2-476e-963d-b2daf143ffb9": "SQLVMResourceProviderAuth",
    "844cca35-0656-46ce-b636-13f48b0eecbd": "Microsoft Stream Mobile Native",
    "810dcf14-1858-4bf2-8134-4c369fa3235b": "Azure AD Identity Governance - Entitlement Management",
    "00000003-0000-0ff1-ce00-000000000000": "Office 365 SharePoint Online",
    "2d4d3d8e-2be3-4bef-9f87-7875a61c29de": "OneNote",
    "055caf97-1b4f-4730-9f5d-acc24b707b06": "Liftr-Monitoring-First-Party",
    "6f82282e-0070-4e78-bc23-e6320c5fa7de": "Microsoft Discovery Service",
    "cfbd4387-1a16-4945-83c0-ec10e46cd4da": "Azure Security for IoT",
    "a6aa9161-5291-40bb-8c5c-923b567bee3b": "Storage Resource Provider",
    "0cb7b9ec-5336-483b-bc31-b15b5788de71": "ASM Campaign Servicing",
    "0f6e3eff-886c-4f7a-a1d7-6f1f0177273b": "Intune oAuth Graph",
    "608f6f31-fed0-4f7b-809f-90f6c9b3de78": "Azure Maps Resource Provider",
    "0000dab9-8b21-4ba2-807f-1743968cef00": "ASE-Arc-Integration",
    "abfa0a7c-a6b6-4736-8310-5855508787cd": "Microsoft Azure App Service",
    "d6d855d0-705d-4f41-8a67-215ffa52110a": "Microsoft.IoTFirmwareDefense.Prod",
    "ab3be6b7-f5df-413d-ac2d-abf1e3fd9c0b": "Microsoft Teams Graph Service",
    "a150d169-7d37-47dd-9b20-156207b7b02f": "MIP Exchange Solutions",
    "b9a92e36-2cf8-4f4e-bcb3-9d99e00e14ab": "Compute Recommendation Service",
    "8d5683a1-43b9-4f38-8906-504eae3c36c9": "Identity Scenario Monitoring",
    "00000005-0000-0ff1-ce00-000000000000": "Viva Engage",
    "57c0fc58-a83a-41d0-8ae9-08952659bdfd": "Azure Cosmos DB Virtual Network To Network Resource Provider",
    "6e02f8e9-db9b-4eb5-aa5a-7c8968375f68": "NetworkVerifier",
    "1a4b5304-a0fd-4017-8a3d-466fc083b73e": "MSATenantRestrictions",
    "f3b07414-6bf4-46e6-b63f-56941f3f4128": "Microsoft Power Query",
    "8fca0a66-c008-4564-a876-ab3ae0fd5cff": "Microsoft.SMIT",
    "80331ee5-4436-4815-883e-93bc833a9a15": "Universal Print Connector",
    "55441455-2f54-42b5-bc99-93e21cd4ae28": "Office Enterprise Protection Service",
    "2746ea77-4702-4b45-80ca-3c97e680e8b7": "Azure Data Explorer",
    "c61d67cf-295a-462c-972f-33af37008751": "Call Quality Dashboard",
    "db55028d-e5ba-420f-816a-d18c861aefdf": "Microsoft Office Licensing Service vNext",
    "3b511579-5e00-46e1-a89e-a6f0870e2f5a": "Windows 365 Portal",
    "6208afad-753e-4995-bbe1-1dfd204b3030": "Teams ACL management service",
    "374b2a64-3b6b-436b-934c-b820eacca870": "Azure Media Services",
    "80dbdb39-4f33-4799-8b6f-711b5e3e61b6": "Billing RP",
    "aaf3f152-fe17-487b-b671-44d3f7bad293": "Mimir",
    "65d91a3d-ab74-42e6-8a2f-0add61688c74": "Microsoft Approval Management",
    "c699bf69-fb1d-4eaf-999b-99e6b2ae4d85": "ClusterConfigToConnectedCluster",
    "d3ee6f25-becc-4659-9bc6-bbe6af7d18e6": "OneLTI",
    "f8f7a2aa-e116-4ba6-8aea-ca162cfa310d": "Microsoft Graph Connectors Core",
    "2368d027-f996-4edb-bf48-928f98f2ab8c": "DoNotDelete-DataBoxEdgeNGatewayManagedApp",
    "cf6c77f8-914f-4078-baef-e39a5181158b": "Microsoft Teams Settings Store",
    "f09d1391-098c-47d7-ac7e-6ed2afc5016b": "MicrosoftAzureADFulfillment",
    "04b07795-8ddb-461a-bbee-02f9e1bf7b46": "Microsoft Azure CLI",
    "7d9b9ef5-b3c8-45ea-87bc-2da008dc4f72": "Microsoft B2B Cross Cloud Worker - Government",
    "6bc3b958-689b-49f5-9006-36d165f30e00": "Teams CMD Services Artifacts",
    "9d3e55ba-79e0-4b7c-af50-dc460b81dca1": "Microsoft Azure Data Catalog",
    "00000014-0000-0000-c000-000000000000": "Microsoft.Azure.SyncFabric",
    "b55b276d-2b09-4ad2-8de5-f09cf24ffba9": "Microsoft Teams - Teams And Channels Service",
    "3274406e-4e0a-4852-ba4f-d7226630abb7": "Azure Healthcare APIs RBAC",
    "19b21e10-1304-498b-92d4-4290e94999fa": "Deprecated - CAS API Security RP Staging",
    "f5fe7750-c730-4d4f-8517-0b1ad5bd2bd5": "CAP Package Deployer Service IM",
    "7e468355-e4db-46a9-8289-8d414c89c43c": "Federated Profile Service",
    "fc03f97a-9db0-4627-a216-ec98ce54e018": "Azure AD Notification",
    "fc75330b-179d-49af-87dd-3b1acf6827fa": "AzureAutomation",
    "4c9fc70a-8d18-4528-9113-c6f1318c4d89": "CAP Package Deployer Service",
    "0a0a29f9-0a25-49c7-94bf-c53c3f8fa69d": "Cortana Experience with O365",
    "b4ca0290-4e73-4e31-ade0-c82ecfaabf6a": "Azure DNS Managed Resolver",
    "7c99d979-3b9c-4342-97dd-3239678fb300": "Data Classification Service",
    "80369ed6-5f11-4dd9-bef3-692475845e77": "Microsoft.EventHubs",
    "76cd24bf-a9fc-4344-b1dc-908275de6d6d": "Azure SQL Virtual Network to Network Resource Provider",
    "75cba773-c367-4ba4-8d4f-65f91b68c384": "Grade Sync",
    "f0ae4899-d877-4d3c-ae25-679e38eea492": "AAD App Management",
    "22d7579f-06c2-4baa-89d2-e844486adb9d": "Cortana at Work Bing Services",
    "26a18ebc-cdf7-4a6a-91cb-beb352805e81": "Skype Teams Calling API Service",
    "e9b154d0-7658-433b-bb25-6b8e0a8a7c59": "Outlook Lite",
    "cb250467-fc8f-4c42-8349-9ff9e9a17b02": "Deprecated - CAS API Security RP Dev",
    "df77edef-903d-416b-bcc0-cc8b91af54ea": "Defender for IoT",
    "608f9929-9737-432e-860f-4e1c1821052f": "Azure VMware Solution RP",
    "fbb0ac1a-82dd-478b-a0e5-0b2b98ef38fe": "Substrate-FileWatcher",
    "aad98258-6bb0-44ed-a095-21506dfb68fe": "Universal Print PS Module",
    "67a65d0c-1fdb-4698-acd3-4ea44058e1c3": "Azure AD Publisher Service",
    "4e445925-163e-42ca-b801-9073bfa46d17": "SharePoint Home Notifier",
    "bf7b96b3-68e4-4fd9-b697-637f0f1e778c": "Universal Store Entitlements Service",
    "e3bfd6ac-eace-4438-9dc1-eed439e738de": "MicrosoftMigrateProject",
    "dc3294af-4679-418f-a30c-76948e23fe1c": "Microsoft Kaizala",
    "1220eac7-3b19-4572-be70-aa544a2e5f74": "Microsoft Security DevOps",
    "d0597157-f0ae-4e23-b06c-9e65de434c4f": "Microsoft Teams Task Service",
    "eace8149-b661-472f-b40d-939f89085bd4": "Substrate Instant Revocation Pipeline",
    "7ae5462d-d9d1-42f6-93ca-198d7b0ca997": "Microsoft O365 Scuba",
    "944f0bd1-117b-4b1c-af26-804ed95e767e": "Media Analysis and Transformation Service",
    "d52485ee-4609-4f6b-b3a3-68b6f841fa23": "On-Premises Data Gateway Connector",
    "2bb78a2a-f8f1-4bc3-8ecf-c1e15a0726e6": "MicrosoftTeamsCortanaSkills",
    "1a5e141d-70dd-4594-8442-9fc46fa48686": "Avs Fleet Rp",
    "b503eb83-1222-4dcc-b116-b98ed5216e05": "Azure Notification Service",
    "f7a2a81e-ab33-4560-a3dd-6ddca3c5ec6d": "Membership View Service",
    "f3a218b7-5c8f-460b-93af-56b072788c15": "Microsoft Workplace Search Service",
    "dcad865d-9257-4521-ad4d-bae3e137b345": "Microsoft SharePoint Online - SharePoint Home",
    "00000013-0000-0000-c000-000000000000": "Azure Classic Portal",
    "1303f293-64bd-48ba-89b0-6bf538bc67f3": "Microsoft Teams IP Policy Service",
    "4c4f550b-42b2-4a16-93f9-fdb9e01bb6ed": "Targeted Messaging Service",
    "737d58c1-397a-46e7-9d12-7d8c830883c2": "Azure Marketplace Container Management API",
    "441509e5-a165-4363-8ee7-bcf0b7d26739": "DWEngineV2",
    "6201d19e-14fb-4472-a2d6-5634a5c97568": "Event Hub MSI App",
    "f6e5c0c2-4746-4152-b162-91309d5556df": "IC3 Modern Effective Config",
    "2b5e68f0-bdc2-45b0-920a-217d5cbbd505": "Power Platform Policy TIRPS CM - PROD",
    "826870f9-9fbb-4f23-81b8-3a957080dfa2": "Medeina Service Dev",
    "1fe0d6b3-81f0-4cf5-9dfd-fbb297d7848c": "Microsoft Insider Risk Management",
    "3eb95cef-b10f-46fe-94e0-969a3d4c9292": "Office 365 Import Service",
    "04687a56-4fc2-4e36-b274-b862fb649733": "MDATPNetworkScanAgent",
    "a47591ab-e23e-4ffa-9e1b-809b9067e726": "Microsoft Teams User Profile Search Service",
    "789e8929-0390-42a2-8934-0f9dafb8ec89": "Exchange Rbac",
    "80ccca67-54bd-44ab-8625-4b79c4dc7775": "Microsoft 365 Security and Compliance Center",
    "0bf30f3b-4a52-48df-9a82-234910c4a086": "Microsoft Graph Change Tracking",
    "d73f4b35-55c9-48c7-8b10-651f6f2acb2e": "MCAPI Authorization Prod",
    "cd1b8394-07a3-43b1-8aba-ce6ee572d0af": "Frontline Worker Orchestrator Service",
    "2c9e12e5-a56c-4ba1-b768-7a141586c6fe": "Viva Learning",
    "7e3bc4fd-85a3-4192-b177-5b8bfc87f42c": "Microsoft Azure Container Apps - Control Plane",
    "3b2fa68d-a091-48c9-95be-88d572e08fb7": "AzureBackupReporting",
    "b861dbcc-a7ef-4219-a005-0e4de4ea7dcf": "Data Export Service for Microsoft Dynamics 365",
    "a70c8393-7c0c-4c1e-916a-811bd476ee11": "Microsoft Defender for Cloud CIEM",
    "d62121f3-e023-4972-b6b0-794190c0fd98": "Office 365 Mover",
    "03db181c-e9d3-4868-9097-f0b728327182": "ClusterConfigToAKS",
    "ca0a114d-6fbc-46b3-90fa-2ec954794ddb": "Microsoft Device Management Checkin",
    "8e14e873-35ba-4720-b787-0bed94370b17": "Microsoft Teams Targeting Application",
    "366cbfa5-46b3-47fb-9d70-55fb923b4833": "Azure Spring Cloud Service Runtime Auth",
    "e8bdeda8-b4a3-4eed-b307-5e2456238a77": "Office365 Shell SS-Server",
    "2db8cb1d-fb6c-450b-ab09-49b6ae35186b": "Microsoft Dynamics CRM Learning Path",
    "0fa37baf-7afc-4baf-ab2d-d5bb891d53ef": "Microsoft Teams ATP Service",
    "2a486b53-dbd2-49c0-a2bc-278bdfc30833": "Cortana at Work Service",
    "e9710088-bcdf-4a36-a7cd-ab24f73dfd23": "Intune PartnerAPI Client Prod",
    "a8adde6c-aeb4-4fd6-9d8f-c2dfdecac60a": "Dynamics 365 collaboration with Microsoft Teams",
    "b51a99a9-ccaa-4687-aa2c-44d1558295f4": "Microsoft Exact Data Match Upload Agent",
    "9c8b80bc-6887-42d0-b1af-d0c40f9bf1fa": "Azure SQL Managed Instance to Azure AD Resource Provider",
    "09abbdfd-ed23-44ee-a2d9-a627aa1c90f3": "ProjectWorkManagement",
    "f738ef14-47dc-4564-b53b-45069484ccc7": "Marketplace Api",
    "c606301c-f764-4e6b-aa45-7caaaea93c9a": "Office Store",
    "66a88757-258c-4c72-893c-3e8bed4d6899": "Office 365 Search Service",
    "d52792f4-ba38-424d-8140-ada5b883f293": "AAD Terms Of Use",
    "5ed8fe41-c1bc-4c06-a531-d91e1f1c2fac": "Azure Database for PostgreSQL Marlin",
    "95c6fb36-bab4-4c0f-9d29-37997c601eb7": "Frontline Worker Orchestrator Service Test",
    "2c220739-d44d-4bf7-ba5f-95cf9fb7f10c": "MIP Exchange Solutions - Teams",
    "1e3e4475-288f-4018-a376-df66fd7fac5f": "NetworkTrafficAnalyticsService",
    "01fc33a7-78ba-4d2f-a4b7-768e336e890e": "MS-PIM",
    "91ad134d-5284-4adc-a896-d7fd24e9fa15": "Microsoft Alchemy Service",
    "ce79fdc4-cd1d-4ea5-8139-e74d7dbe0bb7": "Lifecycle Workflows",
    "cbff9545-769a-4b41-b76e-fbb069e8727e": "Microsoft Defender for Cloud Pricing Resource Provider",
    "19686ca6-5324-4571-a231-77e026b0e06f": "Microsoft Command Service",
    "9ae330ab-d710-466b-851c-c828e7340846": "MicrosoftAutomanaged",
    "92876b03-76a3-4da8-ad6a-0511ffdf8647": "ComplianceWorkbenchApp",
    "0130cc9f-7ac5-4026-bd5f-80a08a54e6d9": "Azure Data Warehouse Polybase",
    "1b912ec3-a9dd-4c4d-a53e-76aa7adb28d7": "AADReporting",
    "78e7bc61-0fab-4d35-8387-09a8d2f5a59d": "Yggdrasil",
    "0e282aa8-2770-4b6c-8cf8-fac26e9ebe1f": "Sherlock",
    "1fd5118e-2576-4263-8130-9503064c837a": "Azure Communication Services",
    "86adf623-eea3-4453-9f4a-18134ac1410d": "Azure Spring Cloud Marketplace Integration",
    "709110f7-976e-4284-8851-b537e9bcb187": "Microsoft Device Management Enrollment",
    "58ea322b-940c-4d98-affb-345ec4cccb92": "M365 Pillar Diagnostics Service",
    "fc68d9e5-1f76-45ef-99aa-214805418498": "Azure AD Identity Protection",
    "207a6836-d031-4764-a9d8-c1193f455f21": "Conference Auto Attendant",
    "96231a05-34ce-4eb4-aa6a-70759cbb5e83": "MicrosoftAzureRedisCache",
    "ef4c7f67-65bd-4506-8179-5ddcc5509aeb": "Skype For Business Entitlement",
    "1690c5aa-925a-4d0e-836b-722c795bd0d0": "Group Configuration Processor",
    "ce6ff14a-7fdc-4685-bbe0-f6afdfcfa8e0": "Azure Linux VM Sign-In",
    "20e940b3-4c77-4b0b-9a53-9e16a1b010a7": "MarketplaceAPI ISV",
    "45a330b1-b1ec-4cc1-9161-9f03992aa49f": "Windows Store for Business",
    "ce48853e-0605-4f77-8746-d70ac63cc6bc": "Bot Framework Composer",
    "b8d56525-1fd0-4121-a640-e0ede64f74b5": "M365CommunicationCompliance",
    "e9f49c6b-5ce5-44c8-925d-015017e9f7ad": "Azure Data Lake",
    "595d87a1-277b-4c0a-aa7f-44f8a068eafc": "Microsoft.SupportTicketSubmission",
    "944861d3-5975-4f8b-afd4-3422c0b1b6ce": "Customer Service Trial PVA",
    "87e86b91-9ae3-4679-b68a-471fe50be746": "Microsoft Managed Policy Manager",
    "39624784-6cbe-4a60-afbe-9f46d10fdb27": "Teams and Skype for Business Administration",
    "95de633a-083e-42f5-b444-a4295d8e9314": "Microsoft Whiteboard Services",
    "797f4846-ba00-4fd7-ba43-dac1f8f63013": "Windows Azure Service Management API",
    "92b61450-2139-4e4a-a0cc-898eced7a779": "Afdx Resource Provider",
    "b2cc270f-563e-4d8a-af47-f00963a71dcd": "OneProfile Service",
    "c92229fa-e4e7-47fc-81a8-01386459c021": "Common Data Service User Management",
    "aa175e40-6f9c-4aa5-856a-4638955d2366": "Machine Learning Services Network Management",
    "ef5d5c69-a5df-46bb-acaf-426f161a21a2": "Managed Service Identity",
    "396e7f4b-41ea-4851-b04d-65de6cf1b4a3": "Azure AD Identity Governance - SPO Management",
    "b692184e-b47f-4706-b352-84b288d2d9ee": "Microsoft.MileIQ.RESTService",
    "18f36947-75b0-49fb-8d1c-29584a55cac5": "Reply-At-Mention",
    "8edd93e1-2103-40b4-bd70-6e34e586362d": "Windows Azure Security Resource Provider",
    "b4114287-89e4-4209-bd99-b7d4919bcf64": "DecomOfficeDelve",
    "00000008-0000-0000-c000-000000000000": "Microsoft.Azure.DataMarket",
    "cdccd920-384b-4a25-897d-75161a4b74c1": "Skype Teams Firehose",
    "88c57617-94ff-4043-a396-8a85a8d38922": "Business Central to Common Data Service",
    "417ae6eb-aac8-42c8-900c-0e50debba688": "Universal Print Enabled Printer",
    "0f54b75d-4d29-4a92-80ae-106a60cd8f5d": "Teams User Engagement Profile Service",
    "c9d36ed4-91b3-4c87-b8d7-68d92826c96c": "Modern Workplace Customer APIs",
    "319f651f-7ddb-4fc6-9857-7aef9250bd05": "K8 Bridge",
    "dda27c27-f274-469f-8005-cce10f270009": "AADPasswordProtectionProxy",
    "03b39d0f-4213-4864-a245-b1476ec03169": "Azure Spring Cloud Domain-Management",
    "c161e42e-d4df-4a3d-9b42-e7a3c31f59d4": "Microsoft Intune API",
    "035f9e1d-4f00-4419-bf50-bf2d87eb4878": "Azure Monitor Restricted",
    "57084ef3-d413-4087-a28f-f6f3b1ad7786": "Branch Connect Web Service",
    "d6fdaa33-e821-4211-83d0-cf74736489e1": "Microsoft Service Trust",
    "823dfde0-1b9a-415a-a35a-1ad34e16dd44": "Microsoft Teams Wiki Images Migration",
    "6dae42f8-4368-4678-94ff-3960e28e3630": "Azure Kubernetes Service AAD Server",
    "98c8388a-4e86-424f-a176-d1288462816f": "Recommended",
    "a4c1cdb3-88ab-4d13-bc99-1c46106f0727": "Marketplace Reviews",
    "6608bce8-e060-4e82-bfd2-67ed4f60262f": "AML Inferencing Frontdoor",
    "00000004-0000-0ff1-ce00-000000000000": "Skype for Business Online",
    "509e4652-da8d-478d-a730-e9d4a1996ca4": "Azure Resource Graph",
    "00000002-0000-0000-c000-000000000000": "Windows Azure Active Directory",
    "51133ff5-8e0d-4078-bcca-84fb7f905b64": "Microsoft Teams Mailhook",
    "2087bd82-7206-4c0a-b305-1321a39e5926": "Microsoft To-Do",
    "26a4ae64-5862-427f-a9b0-044e62572a4f": "Microsoft Intune Checkin",
    "637fcc9f-4a9b-4aaa-8713-a2a3cfda1505": "Dynamics CRM Online Administration",
    "2cf9eb86-36b5-49dc-86ae-9a63135dfa8c": "Azure Traffic Manager and DNS",
    "b2b4502c-fedd-4748-8828-09e1eae11d6a": "Dynamics 365 Universal Resource Scheduling",
    "e0ccf59d-5a20-4a87-a122-f42842cdb86a": "Microsoft Defender for Cloud Scanner Resource Provider",
    "5cfe643a-dd84-4d45-834d-c8d659a72a48": "Virtual Visit APIs",
    "01cb2876-7ebd-4aa4-9cc9-d28bd4d359a9": "Device Registration Service",
    "78827f38-7b69-4d5e-a627-d6fdd9c759a0": "Microsoft.Blockchain Azure Resource Provider",
    "939fe80f-2eef-464f-b0cf-705d254a2cf2": "Power Query Online GCC-L2",
    "1c0ae35a-e2ec-4592-8e08-c40884656fa5": "Skype Team Substrate connector",
    "4962773b-9cdb-44cf-a8bf-237846a00ab7": "Microsoft.EventGrid",
    "8adc51cc-7477-49a4-be4e-263946b4d561": "MIP Exchange Solutions - ODB",
    "2e307cd5-5d2d-4499-b656-a97de9f52708": "Modern Workplace Customer API Native",
    "be5f0473-6b57-40f8-b0a9-b3054b41b99e": "AI Builder Prod Non God Mode",
    "d8c767ef-3e9a-48c4-aef9-562696539b39": "Request Approvals Read Platform",
    "870c4f2e-85b6-4d43-bdda-6ed9a579b725": "Microsoft Information Protection Sync Service",
    "9199bf20-a13f-4107-85dc-02114787ef48": "One Outlook Web",
    "a12e8ccb-0fcd-46f8-b6a1-b9df7a9d7231": "Azure Arc Data Processing Services",
    "dd79bf6f-53fa-4c5f-962b-d029d26a579e": "VoiceApplicationAnalytics",
    "8f348934-64be-4bb2-bc16-c54c96789f43": "EDU Assignments",
    "589d5083-6f11-4d30-a62a-a4b316a14abf": "Azure Key Vault Managed HSM",
    "9e3b502c-b4a1-441d-98fd-28e482bf7e88": "Dynamics 365 Customer Insights - Consent",
    "f8c6c2cc-4c3a-4157-b91c-11034ba01a6e": "Intune AndroidFOTAService ConfidentialClient",
    "1dcb1bc7-c721-498e-b2fa-bcddcea44171": "Microsoft Azure Authorization Resource Provider",
    "891dc8ed-860a-4db7-8988-cb2fa58da3fc": "AAD Staged Rollout",
    "f18b59c9-5926-4a65-8605-c23ec8c7e074": "console-m365d",
    "2cfc91a4-7baa-4a8f-a6c9-5f3d279060b8": "Azure Application Change Service",
    "2634dd23-5e5a-431c-81ca-11710d9079f4": "Microsoft Stream Service",
    "ad40333e-9910-4b61-b281-e3aeeb8c3ef3": "AI Builder Authorization Service",
    "de0853a1-ab20-47bd-990b-71ad5077ac7b": "Windows Configuration Designer (WCD)",
    "5749fa6e-3335-495e-a235-e0a89769841f": "Microsoft Educator Center",
    "febcadd2-4101-4bf8-8be8-f423f21f2ca8": "Graph .NET quick start",
    "c2b3bb2d-34bb-46d7-bc1f-94480c1345a0": "MALogAnalyticsReader",
    "8ef61e4d-38da-4ba8-8b1a-4f9c4989c74b": "Myworkspace-ProdSP",
    "d1ddf0e4-d672-4dae-b554-9d5bdfd93547": "Microsoft Intune PowerShell",
    "25a6a87d-1e19-4c71-9cb0-16e88ff608f1": "Microsoft Cloud App Security (Internal)",
    "c4829704-0edc-4c3d-a347-7c4a67586f3c": "MicrosoftGraphSecurityConnector",
    "fa9ac275-bd92-4ce2-996b-2cce07da7849": "Graph .NET quick start",
    "a4bad4aa-bf02-4631-9f78-a64ffdba8150": "Data Migration Service",
    "7aa75825-1ea2-4cd1-a38c-90c595a91411": "Windows Defender ATP for Flow",
    "cc7b0696-1956-408b-876a-ad6bf2b9890b": "Reset Viral Users Redemption Status",
    "be58d912-b9d5-41a0-8b56-779409e017b8": "Zero Trust Assessment - Dev",
    "dd4c082e-4e78-4792-a772-4821616bad01": "Microsoft Business Solutions",
    "de8bc8b5-d9f9-48b1-a8ad-b748da725064": "Graph Explorer",
    "68bc31c0-f891-4f4c-9309-c6104f7be41b": "Azure AD Assessment",
    "14d82eec-204b-4c2f-b7e8-296a70dab67e": "Microsoft Graph Command Line Tools",
    "2a0c3efa-ba54-4e55-bdc0-770f9e39e9ee": "Azure AD Power BI Content Pack App",
    "f18ab2c3-b542-4c6c-882a-aef7ffb75194": "MIgrateApps_From_ADFS_To_AzureAD",
    "986b68e5-7d5c-44e4-8f79-0f9994555c79": "Intune Test Skill with OBO Authentication",
    "fe6aa35b-7da8-44fd-a44e-e2d4bafbdab5": "Modern Workplace Tools",
    "2a797b48-1dd6-4c0f-97c3-6ca9069dc618": "medeina-openai-proxy-dev",
    "4c46888b-0beb-4907-a200-9ca25a46e8ee": "businesstravelletterPROD",
    "e462442e-6682-465b-a31f-652a88bfbe51": "Microsoft events",
    "09213cdc-9f30-4e82-aa6f-9b6e8d82dab3": "Microsoft Tech Community",
    "9b6c3313-f2b7-4563-a0ac-ea24a8ae44ca": "Resource Coster",
    "205478c0-bd83-4e1b-a9d6-db63a3e1e1c8": "Microsoft.AzureFrontDoor-Cdn",
    "df2798fc-2aed-4c3a-98ae-1776949480c4": "Zero Trust Assessment",
    "17bf704f-25db-4ea9-af47-50b552cbb0f0": "Power Platform Community",
    "0ec2d138-5a70-4a33-b2c7-7d296c996ace": "Microsoft Photos",
    "7798c861-b87f-47e7-8bbc-8f1d0dac9f69": "passivetotal-web-dev",
    "62f85080-9912-4a16-b0be-aff63ee2eeea": "Zero Trust Assessment TBD",
    "c6ef8824-f372-49fd-8055-0d672b2974a7": "Graph JavaScript quick start",
    "ccc737ba-4bcc-4a71-8e38-f0e86310d5e8": "FlowRPCustomConnector",
    "41b23e61-6c1e-4545-b367-cd054e0ed4b4": "Azure VPN",
    "f0cf43e5-8a9b-451c-b2d5-7285c785684d": "Windows Defender Security Intelligence",
    "6c7a5208-a7b3-4813-8e99-3b9e627971c4": "AdithyaHSMultitenantApp",
    "2cdc32be-2d13-4482-9ea9-458d425c56fa": "API Skill with OBO Authentication",
    "3d0500d8-cbc9-4d10-a6ec-8ec4cd23ede9": "WD Antivirus Testground",
    "23523755-3a2b-41ca-9315-f81f3f566a95": "ACOM Azure Website",
    "69893ee3-dd10-4b1c-832d-4870354be3d8": "AEM-DualAuth",
    "7ab7862c-4c57-491e-8a45-d52a7e023983": "App Service",
    "835b2a73-6e10-4aa5-a979-21dfda45231c": "Azure Lab Services Portal",
    "20a11fe0-faa8-4df5-baf2-f965f8f9972e": "ContactsInferencingEmailProcessor",
    "e64aa8bc-8eb4-40e2-898b-cf261a25954f": "CRM Power BI Integration",
    "60c8bde5-3167-4f92-8fdb-059f6176dc0f": "Enterprise Roaming and Backup",
    "497effe9-df71-4043-a8bb-14cf78c4b63b": "Exchange Admin Center",
    "f5eaa862-7f08-448c-9c4e-f4047d4d4521": "FindTime",
    "b669c6ea-1adf-453f-b8bc-6d526592b419": "Focused Inbox",
    "c35cb2ba-f88b-4d15-aa9d-37bd443522e1": "GroupsRemoteApiRestClient",
    "d9b8ec3a-1e4e-4e08-b3c2-5baf00c0fcb0": "HxService",
    "16aeb910-ce68-41d1-9ac3-9e1673ac9575": "IrisSelectionFrontDoor",
    "ee272b19-4411-433f-8f28-5c13cb6fd407": "Microsoft 365 Support Service",
    "29d9ed98-a469-4536-ade2-f981bc1d605e": "Microsoft Authentication Broker",
    "1950a258-227b-4e31-a9cf-717495945fc2": "Microsoft Azure PowerShell",
    "cf36b471-5b44-428c-9ce7-313bf84528de": "Microsoft Bing Search",
    "2d7f3606-b07d-41d1-b9d2-0d0c9296a6e8": "Microsoft Bing Search for Microsoft Edge",
    "1786c5ed-9644-47b2-8aa0-7201292175b6": "Microsoft Bing Default Search Engine",
    "3090ab82-f1c1-4cdf-af2c-5d7a6f3e2cc7": "Microsoft Defender for Cloud Apps",
    "18fbca16-2224-45f6-85b0-f7bf2b39b3f3": "Microsoft Docs",
    "00000015-0000-0000-c000-000000000000": "Microsoft Dynamics ERP",
    "6253bca8-faf2-4587-8f2f-b056d80998a7": "Microsoft Edge Insider Addons Prod",
    "99b904fd-a1fe-455c-b86c-2f9fb1da7687": "Microsoft Exchange ForwardSync",
    "51be292c-a17e-4f17-9a7e-4b661fb16dd2": "Microsoft Exchange ProtectedServiceHost",
    "fb78d390-0c51-40cd-8e17-fdbfab77341b": "Microsoft Exchange REST API Based Powershell",
    "fc0f3af4-6835-4174-b806-f7db311fd2f3": "Microsoft Intune Windows Agent",
    "d3590ed6-52b3-4102-aeff-aad2292ab01c": "Microsoft Office",
    "d176f6e7-38e5-40c9-8a78-3998aab820e7": "Microsoft Online Syndication Partner Portal",
    "871c010f-5e61-4fb1-83ac-98610a7e9110": "Microsoft Power BI",
    "28b567f6-162c-4f54-99a0-6887f387bbcc": "Microsoft Storefronts",
    "fdf9885b-dd37-42bf-82e5-c3129ef5a302": "Microsoft Support",
    "dfe74da8-9279-44ec-8fb2-2aed9e1c73d0": "O365 SkypeSpaces Ingestion Service",
    "4345a7b9-9a63-4910-a426-35363201d503": "O365 Suite UX",
    "00b41c95-dab0-4487-9791-b9d2c32c80f2": "Office 365 Management",
    "93d53678-613d-4013-afc1-62e9e444a0a5": "Office Online Add-in SSO",
    "2abdc806-e091-4495-9b10-b04d93c3f040": "Office Online Client Microsoft Entra ID- Augmentation Loop",
    "b23dd4db-9142-4734-867f-3577f640ad0c": "Office Online Client Microsoft Entra ID- Loki",
    "17d5e35f-655b-4fb0-8ae6-86356e9a49f5": "Office Online Client Microsoft Entra ID- Maker",
    "b6e69c34-5f1f-4c34-8cdf-7fea120b8670": "Office Online Client MSA- Loki",
    "243c63a3-247d-41c5-9d83-7788c43f1c43": "Office Online Core SSO",
    "a9b49b65-0a12-430b-9540-c80b3332c127": "Office Online Search",
    "4b233688-031c-404b-9a80-a4f3f2351f90": "Office.com",
    "89bee1f7-5e6e-4d8a-9f3d-ecd601259da7": "Office365 Shell WCSS-Client",
    "4765445b-32c6-49b0-83e6-1d93765276ca": "OfficeHome",
    "4d5c2d63-cf83-4365-853c-925fd1a64357": "OfficeShredderWacClient",
    "62256cef-54c0-4cb4-bcac-4c67989bdc40": "OMSOctopiPROD",
    "ab9b8c07-8f02-4f72-87fa-80105867a763": "OneDrive SyncEngine",
    "27922004-5251-4030-b22d-91ecd9a37ea4": "Outlook Mobile",
    "a3475900-ccec-4a69-98f5-a65cd5dc5306": "Partner Customer Delegated Admin Offline Processor",
    "bdd48c81-3a58-4ea9-849c-ebea7f6b6360": "Password Breach Authenticator",
    "35d54a08-36c9-4847-9018-93934c62740c": "PeoplePredictions",
    "ae8e128e-080f-4086-b0e3-4c19301ada69": "Scheduling",
    "ffcb16e8-f789-467c-8ce9-f826a080d987": "SharedWithMe",
    "61109738-7d2b-4a0b-9fe3-660b1ff83505": "SpoolsProvisioning",
    "91ca2ca5-3b3e-41dd-ab65-809fa3dffffa": "Sticky Notes API",
    "13937bba-652e-4c46-b222-3003f4d1ff97": "Substrate Context Service",
    "26abc9a8-24f0-4b11-8234-e86ede698878": "SubstrateDirectoryEventProcessor",
    "a970bac6-63fe-4ec5-8884-8536862c42d4": "Substrate Search Settings Management Service",
    "97cb1f73-50df-47d1-8fb0-0271f2728514": "Transcript Ingestion",
    "268761a2-03f3-40df-8a8b-c3db24145b6b": "Universal Store Native Client",
    "3c896ded-22c5-450f-91f6-3d1ef0848f6e": "WeveEngine",
    "a3b79187-70b2-4139-83f9-6016c58cd27b": "WindowsDefenderATP Portal",
    "26a7ee05-5602-4d76-a7ba-eae8b7b67941": "Windows Search",
    "1b3c667f-cde3-4090-b60b-3d2abd0117f0": "Windows Spotlight",
    "c1c74fed-04c9-4704-80dc-9f79a2e515cb": "Yammer Web",
    "e1ef36fd-b883-4dbf-97f0-9ece4b576fc6": "Yammer Web Embed",
    "7ae974c5-1af7-4923-af3a-fb1fd14dcb7e": "OutlookUserSettingsConsumer",
    "5572c4c0-d078-44ce-b81c-6cbf8d3ed39e": "Vortex [wsfed enabled]",
}

_BUILTIN_APPS_NAME_ID = {v: k for k, v in _BUILTIN_APPS_ID_NAME.items()}
